@@ -4,12 +4,12 @@ mod arguments;
 mod column;
 mod connection;
 mod database;
-mod done;
 mod error;
 mod io;
 mod listener;
 mod message;
 mod options;
+mod query_result;
 mod row;
 mod statement;
 mod transaction;
@@ -24,11 +24,11 @@ pub use arguments::{PgArgumentBuffer, PgArguments};
 pub use column::PgColumn;
 pub use connection::PgConnection;
 pub use database::Postgres;
-pub use done::PgDone;
 pub use error::{PgDatabaseError, PgErrorPosition};
 pub use listener::{PgListener, PgNotification};
 pub use message::PgSeverity;
 pub use options::{PgConnectOptions, PgSslMode};
+pub use query_result::PgQueryResult;
 pub use row::PgRow;
 pub use statement::PgStatement;
 pub use transaction::PgTransactionManager;
@@ -44,7 +44,6 @@ pub type PgPoolOptions = crate::pool::PoolOptions<Postgres>;
 impl_into_arguments_for_arguments!(PgArguments);
 impl_executor_for_pool_connection!(Postgres, PgConnection, PgRow);
 impl_executor_for_transaction!(Postgres, PgRow);
-impl_map_row!(Postgres, PgRow);
 impl_acquire!(Postgres, PgConnection);
 impl_column_index_for_row!(PgRow);
 impl_column_index_for_statement!(PgStatement);
