@@ -62,6 +62,7 @@ pub struct SqliteConnectOptions {
     pub(crate) log_settings: LogSettings,
     pub(crate) synchronous: SqliteSynchronous,
     pub(crate) auto_vacuum: SqliteAutoVacuum,
+    pub(crate) page_size: u32,
 }
 
 impl Default for SqliteConnectOptions {
@@ -86,6 +87,7 @@ impl SqliteConnectOptions {
             log_settings: Default::default(),
             synchronous: SqliteSynchronous::Full,
             auto_vacuum: Default::default(),
+            page_size: 4096,
         }
     }
 
@@ -103,6 +105,14 @@ impl SqliteConnectOptions {
         self
     }
 
+    /// Set the [`SQLITE_OPEN_SHAREDCACHE` flag](https://sqlite.org/sharedcache.html).
+    ///
+    /// By default, this is disabled.
+    pub fn shared_cache(mut self, on: bool) -> Self {
+        self.shared_cache = on;
+        self
+    }
+
     /// Sets the [journal mode](https://www.sqlite.org/pragma.html#pragma_journal_mode) for the database connection.
     ///
     /// The default journal mode is WAL. For most use cases this can be significantly faster but
@@ -172,4 +182,12 @@ impl SqliteConnectOptions {
         self.auto_vacuum = auto_vacuum;
         self
     }
+
+    /// Sets the [page_size](https://www.sqlite.org/pragma.html#pragma_page_size) setting for the database connection.
+    ///
+    /// The default page_size setting is 4096.
+    pub fn page_size(mut self, page_size: u32) -> Self {
+        self.page_size = page_size;
+        self
+    }
 }
